/*-
# MS WINDOWS-BASED BARREL(tm)
#
#  wbarrel.h
#
###
#
#  Copyright (c) 2003 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wbarrel.c */

#define IDM_GET		100
#define IDM_WRITE	101
#define IDM_EXIT	102
#define IDM_HIDE	103
#define IDM_UNDO	200
#define IDM_REDO	201
#define IDM_CLEAR	202
#define IDM_PRACTICE	203
#define IDM_RANDOMIZE	204
#define IDM_SOLVE	205
#define IDM_ORIENTIZE	206
#define IDM_PAIRS	207
#define IDM_SPEED	210
#define IDM_SLOW	211
#define IDM_SOUND	212
#define IDM_LEFT	303
#define IDM_RIGHT	301
#define IDM_SHIFT_UP	300
#define IDM_SHIFT_DOWN	302
#define IDM_UP		310
#define IDM_DOWN	312
#define IDM_DECX	403
#define IDM_INCX	401
#define IDM_DECY	400
#define IDM_INCY	402
#define IDM_ABOUT	500
#define IDM_DESCRIPTION	501
#define IDM_FEATURES	502
#define IDM_REFERENCES	503
